@@ -13,8 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import uuid
-
+from oslo_utils import uuidutils
 from zaqarclient.common import decorators
 from zaqarclient.queues.v1 import client
 from zaqarclient.queues.v1 import iterator
@@ -30,25 +29,21 @@ class Client(client.Client):
     :type url: `six.text_type`
     :param version: API Version pointing to.
     :type version: `int`
-    :param options: Extra options:
-        - client_uuid: Custom client uuid. A new one
-        will be generated, if not passed.
-        - auth_opts: Authentication options:
-            - backend
-            - options
-    :type options: `dict`
+    :param conf: CONF object.
+    :type conf: `oslo_config.cfg.CONF`
     """
 
     queues_module = queues
 
-    def __init__(self, url=None, version=2, conf=None):
+    def __init__(self, url=None, version=2, conf=None, session=None):
         self.conf = conf or {}
 
         self.api_url = url
         self.api_version = version
         self.auth_opts = self.conf.get('auth_opts', {})
         self.client_uuid = self.conf.get('client_uuid',
-                                         uuid.uuid4().hex)
+                                         uuidutils.generate_uuid(dashed=False))
+        self.session = session
 
     def queue(self, ref, **kwargs):
         """Returns a queue instance
@@ -61,6 +56,24 @@ class Client(client.Client):
         """
         return queues.Queue(self, ref, **kwargs)
 
+    def queues(self, **params):
+        """Gets a list of queues from the server
+
+        :returns: A list of queues
+        :rtype: `list`
+        """
+        req, trans = self._request_and_transport()
+
+        queue_list = core.queue_list(trans, req, **params)
+
+        count = None
+        if params.get("with_count"):
+            count = queue_list.get("count", None)
+
+        return iterator._Iterator(self, queue_list, 'queues',
+                                  self.queues_module.create_object(self)),\
+            count
+
     @decorators.version(min_version=2)
     def subscription(self, queue_name, **kwargs):
         """Returns a subscription instance
@@ -78,7 +91,7 @@ class Client(client.Client):
         """Gets a list of subscriptions from the server
 
         :param params: Filters to use for getting subscriptions
-        :type params: **kwargs dict.
+        :type params: dict.
 
         :returns: A list of subscriptions
         :rtype: `list`
@@ -103,3 +116,9 @@ class Client(client.Client):
         """Gets the detailed health status of Zaqar server."""
         req, trans = self._request_and_transport()
         return core.health(trans, req)
+
+    @decorators.version(min_version=1.1)
+    def homedoc(self):
+        """Get the detailed resource doc of Zaqar server"""
+        req, trans = self._request_and_transport()
+        return core.homedoc(trans, req)
